You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@servicemix.apache.org by ge...@apache.org on 2009/11/11 20:51:44 UTC

svn commit: r835035 - /servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java

Author: gertv
Date: Wed Nov 11 19:51:44 2009
New Revision: 835035

URL: http://svn.apache.org/viewvc?rev=835035&view=rev
Log:
SMX4-423: servicemix-camel needs access to camel-cxf bundle for namespace handler

Modified:
    servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java

Modified: servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java
URL: http://svn.apache.org/viewvc/servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java?rev=835035&r1=835034&r2=835035&view=diff
==============================================================================
--- servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java (original)
+++ servicemix/components/engines/servicemix-camel/trunk/src/main/java/org/apache/servicemix/camel/osgi/OsgiCamelJbiComponent.java Wed Nov 11 19:51:44 2009
@@ -45,7 +45,7 @@
  * When deploying a JBI packaged SU to camel component, camel-spring and camel-osgi 
  * can not be found by Spring/XBean, thus leading to an exception about the spring 
  * and osgi namespaces not being found.  We need to hack the classloader for SUs to 
  * force a reference to camel-spring and camel-osgi in the SU classloader parents.
  *
  * We also need to inject the bundleContext into the CamelContextFactoryBean to 
  * make sure the CamelContextFactoryBean will replace the regular ResolverUtils 
@@ -131,7 +131,7 @@
             for (Bundle bundle : bundleContext.getBundles()) {
                 try {
                     String symbolicName = bundle.getSymbolicName();
-                    if (symbolicName.contains("camel-spring") || symbolicName.contains("camel-osgi")) {
+                    if (symbolicName.contains("camel-spring") || symbolicName.contains("camel-osgi") || symbolicName.contains("camel-cxf")) {
                         parents.add(BundleDelegatingClassLoader.createBundleClassLoaderFor(bundle));
                     }
                 } catch (Throwable e) {
@@ -45,7 +45,7 @@
  * can not be found by Spring/XBean, thus leading to an exception about the spring 
  * and osgi namespaces not being found.  We need to hack the classloader for SUs to 
- * force a reference to camel-spring and camel-osgi in the SU classloader parents.
+ * force a reference to camel-spring, camel-osgi and camel-cxf in the SU classloader parents.
  *
  * We also need to inject the bundleContext into the CamelContextFactoryBean to 